@@ -10,7 +10,7 @@ The module datahub is the data manager in GeospaceLab. The datahub has three cor
 """
 
 # Licensed under the BSD 3-Clause License
-# Copyright (C) 2021 GeospaceLab (geospacelab)
+# Copyright (C) 2021 GeospaceLAB (geospacelab)
 # Author: Lei Cai, Space Physics and Astronomy, University of Oulu
 
 __author__ = "Lei Cai"
@@ -239,7 +239,7 @@ class DataHub(object):
             dataset = dataset_class(name='temporary', **kwargs)
             self._append_dataset(dataset)
             return dataset
-        elif len(args) == 0 and kind == "user-defined":
+        elif len(args) == 0 and kind in ["user-defined", "UserDefined", "UD"]:
             kwargs.pop('datasets', None)
             dataset = DatasetUser(name='', **kwargs)
             self._append_dataset(dataset)
